package com.ruoyi.web.controller.base;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.RobotOpsPlayPlan;
import com.ruoyi.base.service.IRobotOpsPlayPlanService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 播放方案Controller
 *
 * @author ruoyi
 * @date 2026-05-11
 */
@RestController
@RequestMapping("/base/plan")
public class RobotOpsPlayPlanController extends BaseController
{
    @Autowired
    private IRobotOpsPlayPlanService robotOpsPlayPlanService;

    /**
     * 查询播放方案列表
     */
    @PreAuthorize("@ss.hasPermi('base:plan:list')")
    @GetMapping("/list")
    public TableDataInfo list(RobotOpsPlayPlan robotOpsPlayPlan)
    {
        startPage();
        List<RobotOpsPlayPlan> list = robotOpsPlayPlanService.selectRobotOpsPlayPlanList(robotOpsPlayPlan);
        return getDataTable(list);
    }

    /**
     * 导出播放方案列表
     */
    @PreAuthorize("@ss.hasPermi('base:plan:export')")
    @Log(title = "播放方案", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RobotOpsPlayPlan robotOpsPlayPlan)
    {
        List<RobotOpsPlayPlan> list = robotOpsPlayPlanService.selectRobotOpsPlayPlanList(robotOpsPlayPlan);
        ExcelUtil<RobotOpsPlayPlan> util = new ExcelUtil<RobotOpsPlayPlan>(RobotOpsPlayPlan.class);
        util.exportExcel(response, list, "播放方案数据");
    }

    /**
     * 获取播放方案详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:plan:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(robotOpsPlayPlanService.selectRobotOpsPlayPlanById(id));
    }

    /**
     * 新增播放方案
     */
    @PreAuthorize("@ss.hasPermi('base:plan:add')")
    @Log(title = "播放方案", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RobotOpsPlayPlan robotOpsPlayPlan)
    {
        return toAjax(robotOpsPlayPlanService.insertRobotOpsPlayPlan(robotOpsPlayPlan));
    }

    /**
     * 修改播放方案
     */
    @PreAuthorize("@ss.hasPermi('base:plan:edit')")
    @Log(title = "播放方案", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RobotOpsPlayPlan robotOpsPlayPlan)
    {
        return toAjax(robotOpsPlayPlanService.updateRobotOpsPlayPlan(robotOpsPlayPlan));
    }

    /**
     * 删除播放方案
     */
    @PreAuthorize("@ss.hasPermi('base:plan:remove')")
    @Log(title = "播放方案", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(robotOpsPlayPlanService.deleteRobotOpsPlayPlanByIds(ids));
    }
}
